==> cr12g-panhuo-impl-3.0.0-20210511.123518-21-sources.jar: com/ejianc/business/asset/bean/MaterialDealEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.asset.bean.MaterialDealDetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 报废处置主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_material_deal")
public class MaterialDealEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="commit_date")
    private java.util.Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人编码
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_type_code")
    private String projectTypeCode; // 项目性质编码
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目性质名称
    @TableField(value="org_id")
    private Long orgId; // 组织Id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="deal_user_name")
    private String dealUserName; // 处置人
    @TableField(value="deal_money")
    private java.math.BigDecimal dealMoney; // 处置总金额
    @TableField(value="deal_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date dealDate; // 处置日期
    @TableField(value="finish_state")
    private Integer finishState; // 是否处置完成0未处置1已处置
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="belong_type")
    private Integer belongType; // 0项目1公司
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="materialDealDetailService", pidName = "pId")
    private List<MaterialDealDetailEntity> materialDealDetail = new ArrayList<>(); // 报废处置子表
    

    /**
     * 提交日期
     */
    public java.util.Date getCommitDate() {
        return commitDate;
    }

    /**
     * 提交日期
     */
    public void setCommitDate(java.util.Date commitDate) {
        this.commitDate = commitDate;
    }
    /**
     * 提交人名称
     */
    public String getCommitUserName() {
        return commitUserName;
    }

    /**
     * 提交人名称
     */
    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    /**
     * 提交人编码
     */
    public String getCommitUserCode() {
        return commitUserCode;
    }

    /**
     * 提交人编码
     */
    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目Id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目Id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目性质编码
     */
    public String getProjectTypeCode() {
        return projectTypeCode;
    }

    /**
     * 项目性质编码
     */
    public void setProjectTypeCode(String projectTypeCode) {
        this.projectTypeCode = projectTypeCode;
    }
    /**
     * 项目性质名称
     */
    public String getProjectTypeName() {
        return projectTypeName;
    }

    /**
     * 项目性质名称
     */
    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人id
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 处置人
     */
    public String getDealUserName() {
        return dealUserName;
    }

    /**
     * 处置人
     */
    public void setDealUserName(String dealUserName) {
        this.dealUserName = dealUserName;
    }
    /**
     * 处置总金额
     */
    public java.math.BigDecimal getDealMoney() {
        return dealMoney;
    }

    /**
     * 处置总金额
     */
    public void setDealMoney(java.math.BigDecimal dealMoney) {
        this.dealMoney = dealMoney;
    }
    /**
     * 处置日期
     */
    public java.util.Date getDealDate() {
        return dealDate;
    }

    /**
     * 处置日期
     */
    public void setDealDate(java.util.Date dealDate) {
        this.dealDate = dealDate;
    }
    /**
     * 是否处置完成0未处置1已处置
     */
    public Integer getFinishState() {
        return finishState;
    }

    /**
     * 是否处置完成0未处置1已处置
     */
    public void setFinishState(Integer finishState) {
        this.finishState = finishState;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }

    public List<MaterialDealDetailEntity> getMaterialDealDetail() {
        return materialDealDetail;
    }

    public void setMaterialDealDetail(List<MaterialDealDetailEntity> materialDealDetail) {
        this.materialDealDetail = materialDealDetail;
    }
}

==> cr12g-panhuo-impl-3.0.0-20210514.122043-38-sources.jar: com/ejianc/business/asset/bean/MaterialDealEntity.java <==
package com.ejianc.business.asset.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.asset.vo.MaterialDealDocVO;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.asset.bean.MaterialDealDetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 报废处置主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_material_deal")
public class MaterialDealEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="commit_date")
    private java.util.Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人编码
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_type_code")
    private String projectTypeCode; // 项目性质编码
    @TableField(value="project_type_name")
    private String projectTypeName; // 项目性质名称
    @TableField(value="org_id")
    private Long orgId; // 组织Id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="deal_user_name")
    private String dealUserName; // 处置人
    @TableField(value="deal_total_money")
    private java.math.BigDecimal dealTotalMoney; // 处置总金额
    @TableField(value="deal_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date dealDate; // 处置日期
    @TableField(value="finish_state")
    private Integer finishState; // 是否处置完成0未处置1已处置
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="belong_type")
    private Integer belongType; // 0项目1公司
    @TableField(value="bill_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date billDate; // 编制日期
    @TableField(value="area")
    private String area; // 所属区域
    
    @TableField(exist=false)
    @SubEntity(serviceName="materialDealDetailService", pidName = "pId")
    private List<MaterialDealDetailEntity> materialDealDetail = new ArrayList<>(); // 报废处置子表

    @TableField(exist=false)
    @SubEntity(serviceName="materialDealDocService", pidName = "pId")
    private List<MaterialDealDocEntity> materialDealDoc = new ArrayList<>();


    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }

    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }

    /**
     * 提交日期
     */
    public java.util.Date getCommitDate() {
        return commitDate;
    }

    /**
     * 提交日期
     */
    public void setCommitDate(java.util.Date commitDate) {
        this.commitDate = commitDate;
    }
    /**
     * 提交人名称
     */
    public String getCommitUserName() {
        return commitUserName;
    }

    /**
     * 提交人名称
     */
    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    /**
     * 提交人编码
     */
    public String getCommitUserCode() {
        return commitUserCode;
    }

    /**
     * 提交人编码
     */
    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目Id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目Id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目性质编码
     */
    public String getProjectTypeCode() {
        return projectTypeCode;
    }

    /**
     * 项目性质编码
     */
    public void setProjectTypeCode(String projectTypeCode) {
        this.projectTypeCode = projectTypeCode;
    }
    /**
     * 项目性质名称
     */
    public String getProjectTypeName() {
        return projectTypeName;
    }

    /**
     * 项目性质名称
     */
    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 经办人id
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人id
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 处置人
     */
    public String getDealUserName() {
        return dealUserName;
    }

    /**
     * 处置人
     */
    public void setDealUserName(String dealUserName) {
        this.dealUserName = dealUserName;
    }

    public BigDecimal getDealTotalMoney() {
        return dealTotalMoney;
    }

    public void setDealTotalMoney(BigDecimal dealTotalMoney) {
        this.dealTotalMoney = dealTotalMoney;
    }

    /**
     * 处置日期
     */
    public java.util.Date getDealDate() {
        return dealDate;
    }

    /**
     * 处置日期
     */
    public void setDealDate(java.util.Date dealDate) {
        this.dealDate = dealDate;
    }
    /**
     * 是否处置完成0未处置1已处置
     */
    public Integer getFinishState() {
        return finishState;
    }

    /**
     * 是否处置完成0未处置1已处置
     */
    public void setFinishState(Integer finishState) {
        this.finishState = finishState;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }

    public List<MaterialDealDetailEntity> getMaterialDealDetail() {
        return materialDealDetail;
    }

    public void setMaterialDealDetail(List<MaterialDealDetailEntity> materialDealDetail) {
        this.materialDealDetail = materialDealDetail;
    }

    public List<MaterialDealDocEntity> getMaterialDealDoc() {
        return materialDealDoc;
    }

    public void setMaterialDealDoc(List<MaterialDealDocEntity> materialDealDoc) {
        this.materialDealDoc = materialDealDoc;
    }
}
